.. _Citations:

Citation
========

TauREx will output a bibliography at program finish for components used in a run (including plugins) or store a ``.bib``
file when run with ``--bibtex filename.bib``. We also list references for components in the base TauREx3 installation.



Taurex 3
---------
If you use TauREx 3 in your research and publications,
please cite the arXiv preprint_ or the submitted publication::

    TauREx III: A fast, dynamic and extendable framework for retrievals
    A. F. Al-Refaie, Q. Changeat, I.P. Waldmann and G. Tinetti
    ApJ, submitted, 2019


Retrieval
---------

If you make use of any of these samplers then please cite the relevant papers

*PyMultiNest* and *MultiNest* ::

    (PyMultiNest)
    X-ray spectral modelling of the AGN obscuring region in the CDFS: Bayesian model selection and catalogue
    J. Buchner, A. Georgakakis, K. Nandra, L. Hsu, C. Rangel, M. Brightman, A. Merloni, M. Salvato, J. Donley and D. Kocevski
    A&A, 564 (2014) A125
    doi: 10.1051/0004-6361/201322971
    
    MultiNest: an efficient and robust Bayesian inference tool for cosmology and particle physics
    F. Feroz, M.P. Hobson, M. Bridges
    Mon. Not. Roy. Astron. Soc. 398: 1601-1614,2009
    doi: 10.1111/j.1365-2966.2009.14548.x

*PolyChord* ::

    polychord: next-generation nested sampling 
    W. J. Handley, M. P. Hobson, A. N. Lasenby
    Mon. Not. Roy. Astron. Soc. 453: 4384–4398,2015
    doi: 10.1093/mnras/stv1911

*dyPolyChord* ::
    
    Dynamic nested sampling: an improved algorithm for parameter estimation and evidence calculation
    E. Higson, W. Handley, M. Hobson, A. Lasenby
    Statistics and Computing volume 29, 891–913, 2019
    doi: 10.1007/s11222-018-9844-0


.. _preprint: https://arxiv.org/abs/1912.07759

